content

package
v1.5.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 25, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package content analyzes the textual content of SKILL.md files. It computes metrics such as word count, code block ratio, imperative sentence ratio, information density, and instruction specificity to assess content quality.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Analyze

func Analyze(content string) *types.ContentReport

Analyze computes content metrics for SKILL.md content.

Types

This section is empty.

Jump to